@@ -1,7 +1,12 @@
 ﻿using System;
 
 namespace OpenBveApi.Runtime {
-
+	
+	/* ----------------------------------------------------
+	 * This part of the API is stable as of openBVE 1.2.10.
+	 * Any modification must retain backward compatibility.
+	 * ---------------------------------------------------- */
+	
 	// --- load ---
 	
 	/// <summary>Represents the handle to a sound.</summary>
@@ -208,7 +213,7 @@ namespace OpenBveApi.Runtime {
 		/// <summary>Gets the index of the brake notch that corresponds to 70% of the available brake notches.</summary>
 		public int B67Notch {
 			get {
-				return (int)Math.Round(0.7 * this.MyBrakeNotches);
+				return (int)System.Math.Round(0.7 * this.MyBrakeNotches);
 			}
 		}
 		/// <summary>Gets the number of cars the train has.</summary>
@@ -568,37 +573,37 @@ namespace OpenBveApi.Runtime {
 	
 	/// <summary>Represents a virtual key.</summary>
 	public enum VirtualKeys {
-		/// <summary>The virtual S key. The default assignment is Space. The numerical value of this constant is 0.</summary>
+		/// <summary>The virtual S key. The default assignment is [Space]. The numerical value of this constant is 0.</summary>
 		S = 0,
-		/// <summary>The virtual A1 key. The default assignment is Insert. The numerical value of this constant is 1.</summary>
+		/// <summary>The virtual A1 key. The default assignment is [Insert]. The numerical value of this constant is 1.</summary>
 		A1 = 1,
-		/// <summary>The virtual A2 key. The default assignment is Delete. The numerical value of this constant is 2.</summary>
+		/// <summary>The virtual A2 key. The default assignment is [Delete]. The numerical value of this constant is 2.</summary>
 		A2 = 2,
-		/// <summary>The virtual B1 key. The default assignment is Home. The numerical value of this constant is 3.</summary>
+		/// <summary>The virtual B1 key. The default assignment is [Home]. The numerical value of this constant is 3.</summary>
 		B1 = 3,
-		/// <summary>The virtual B2 key. The default assignment is End. The numerical value of this constant is 4.</summary>
+		/// <summary>The virtual B2 key. The default assignment is [End]. The numerical value of this constant is 4.</summary>
 		B2 = 4,
-		/// <summary>The virtual C1 key. The default assignment is Page Up. The numerical value of this constant is 5.</summary>
+		/// <summary>The virtual C1 key. The default assignment is [PageUp]. The numerical value of this constant is 5.</summary>
 		C1 = 5,
-		/// <summary>The virtual C2 key. The default assignment is Page Down. The numerical value of this constant is 6.</summary>
+		/// <summary>The virtual C2 key. The default assignment is [PageDown]. The numerical value of this constant is 6.</summary>
 		C2 = 6,
-		/// <summary>The virtual D key. The default assignment is 2. The numerical value of this constant is 7.</summary>
+		/// <summary>The virtual D key. The default assignment is [2]. The numerical value of this constant is 7.</summary>
 		D = 7,
-		/// <summary>The virtual E key. The default assignment is 3. The numerical value of this constant is 8.</summary>
+		/// <summary>The virtual E key. The default assignment is [3]. The numerical value of this constant is 8.</summary>
 		E = 8,
-		/// <summary>The virtual F key. The default assignment is 4. The numerical value of this constant is 9.</summary>
+		/// <summary>The virtual F key. The default assignment is [4]. The numerical value of this constant is 9.</summary>
 		F = 9,
-		/// <summary>The virtual G key. The default assignment is 5. The numerical value of this constant is 10.</summary>
+		/// <summary>The virtual G key. The default assignment is [5]. The numerical value of this constant is 10.</summary>
 		G = 10,
-		/// <summary>The virtual H key. The default assignment is 6. The numerical value of this constant is 11.</summary>
+		/// <summary>The virtual H key. The default assignment is [6]. The numerical value of this constant is 11.</summary>
 		H = 11,
-		/// <summary>The virtual I key. The default assignment is 7. The numerical value of this constant is 12.</summary>
+		/// <summary>The virtual I key. The default assignment is [7]. The numerical value of this constant is 12.</summary>
 		I = 12,
-		/// <summary>The virtual J key. The default assignment is 8. The numerical value of this constant is 13.</summary>
+		/// <summary>The virtual J key. The default assignment is [8]. The numerical value of this constant is 13.</summary>
 		J = 13,
-		/// <summary>The virtual K key. The default assignment is 9. The numerical value of this constant is 14.</summary>
+		/// <summary>The virtual K key. The default assignment is [9]. The numerical value of this constant is 14.</summary>
 		K = 14,
-		/// <summary>The virtual L key. The default assignment is 0. The numerical value of this constant is 15.</summary>
+		/// <summary>The virtual L key. The default assignment is [0]. The numerical value of this constant is 15.</summary>
 		L = 15
 	}
 	
